@@ -1,11 +1,12 @@
-# Copyrights 1999,2001-2007 by Mark Overmeer.
+# Copyrights 1999,2001-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.03.
+# Pod stripped from pm file by OODoc 1.05.
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '1.22';
+$VERSION = '1.26';
+
 
 use strict;
 
@@ -241,6 +242,7 @@ application/index.vnd
 application/iotp
 application/ipp
 application/isup
+application/json		json				8bit
 application/javascript		js				8bit
 application/mac-binhex40	hqx				8bit
 application/macwriteii
@@ -414,7 +416,7 @@ application/vnd.kde.kspread	ksp
 application/vnd.kde.kword	kwd,kwt
 application/vnd.kenameapp	htke
 application/vnd.kidspiration	kia
-application/vnd.Kinar		kne,knp,sdf
+application/vnd.Kinar		kne,knp
 application/vnd.google-earth.kml+xml			kml	8bit
 application/vnd.google-earth.kmz			kmz	8bit
 application/vnd.koan
@@ -457,14 +459,21 @@ application/vnd.mozilla.xul+xml	xul
 application/vnd.ms-artgalry	cil
 application/vnd.ms-asf		asf
 application/vnd.mseq		mseq
+application/vnd.ms-excel.sheet.binary.macroEnabled.12 xlsb
+application/vnd.ms-excel.sheet.macroEnabled.12 xlsm
 application/vnd.ms-excel	xls,xlt			base64
 application/vnd.msign
 application/vnd.ms-lrm		lrm
 application/vnd.ms-powerpoint	ppt,pps,pot		base64
+application/vnd.ms-powerpoint.presentation.macroEnabled.12 pptm
+application/vnd.ms-powerpoint.slideshow.macroEnabled.12 ppsm
 application/vnd.ms-project	mpp			base64
 application/vnd.ms-tnef					base64
+application/vnd.ms-word.document.macroEnabled.12 docm
+application/vnd.ms-word.template.macroEnabled.12 dotm
 application/vnd.ms-works				base64
 application/vnd.ms-wpl		wpl			base64
+application/vnd.ms-xpsdocument	xps			8bit
 application/vnd.musician
 application/vnd.music-niff
 application/vnd.nervana		ent,entity,req,request,bkm,kcm
@@ -477,7 +486,26 @@ application/vnd.nokia.radio-presets	rpss
 application/vnd.novadigm.EDM
 application/vnd.novadigm.EDX
 application/vnd.novadigm.EXT
+application/vnd.oasis.opendocument.text			odt
+application/vnd.oasis.opendocument.text-template	ott
+application/vnd.oasis.opendocument.text-web		oth
+application/vnd.oasis.opendocument.text-master		odm
+application/vnd.oasis.opendocument.graphics		odg
+application/vnd.oasis.opendocument.graphics-template	otg
+application/vnd.oasis.opendocument.presentation		odp
+application/vnd.oasis.opendocument.presentation-template	otp
+application/vnd.oasis.opendocument.spreadsheet		ods
+application/vnd.oasis.opendocument.spreadsheet-template	ots
+application/vnd.oasis.opendocument.chart		odc
+application/vnd.oasis.opendocument.formula		odf
+application/vnd.oasis.opendocument.database		odb
+application/vnd.oasis.opendocument.image		odi
 application/vnd.obn
+application/vnd.openxmlformats-officedocument.spreadsheetml.sheet xlsx quoted-printable
+application/vnd.openxmlformats-officedocument.wordprocessingml.template dotx
+application/vnd.openxmlformats-officedocument.presentationml.slideshow ppsx
+application/vnd.openxmlformats-officedocument.presentationml.presentation pptx
+application/vnd.openxmlformats-officedocument.wordprocessingml.document docx
 application/vnd.osa.netdeploy
 application/vnd.palm		prc,pdb,pqa,oprc
 application/vnd.paos.xml
@@ -516,6 +544,13 @@ application/vnd.smaf			mmf
 application/vnd.sss-cod
 application/vnd.sss-dtf
 application/vnd.sss-ntf
+application/vnd.stardivision.chart	sds
+application/vnd.stardivision.calc	sdc
+application/vnd.stardivision.writer	sdw
+application/vnd.stardivision.writer-global	sgl
+application/vnd.stardivision.draw	sda
+application/vnd.stardivision.impress	sdd
+application/vnd.stardivision.math	sdf
 application/vnd.street-stream
 application/vnd.sun.xml.calc		sxc
 application/vnd.sun.xml.calc.template	stc
@@ -625,7 +660,7 @@ application/x-mac-compactpro	cpt
 application/x-maker		frm,maker,frame,fm,fb,book,fbdoc
 application/x-mathcad	# mcd, but there is also vnd.mcd
 application/x-mif		mif
-application/xml			xml xsl				8bit
+application/xml			xml,xsl				8bit
 application/xml-dtd		dtd				8bit
 application/xml-external-parsed-entity
 application/x-msaccess			mda,mdb,mde,mdf		base64
@@ -802,7 +837,7 @@ message/external-body							8bit
 message/http
 message/news								8bit
 message/partial								8bit
-message/rfc822								8bit
+message/rfc822				eml				8bit
 message/s-http
 message/sip
 message/sipfrag
@@ -876,6 +911,7 @@ text/vnd.wap.wmlscript			wmls
 text/vnd.wap.wml			wml
 text/xml-external-parsed-entity
 text/xml
+text/x-component			htc				8bit
 text/x-setext				etx
 text/x-sgml				sgml,sgm			8bit
 text/x-vCalendar			vcs				8bit
